==> u++_5.0.1.orig.tar.gz: u++-5.0.1/src/scheduler/uDeadlineMonotonicStatic.h <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.0.1, Copyright (C) Ashif S. Harji 2000
// 
// uDeadlineMonotonic.h -- 
// 
// Author           : Ashif S. Harji
// Created On       : Fri Oct 27 16:09:42 2000
// Last Modified By : Peter A. Buhr
// Last Modified On : Thu Jun 28 16:58:40 2001
// Update Count     : 149
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __U_DEADLINEMONOTONICSTATIC_H__
#define __U_DEADLINEMONOTONICSTATIC_H__

#pragma __U_NOT_USER_CODE__


#include <uRealTime.h>
#include <uStaticPriorityQ.h>


class uDeadlineMonotonicStatic : public uStaticPriorityScheduleSeq<uBaseTaskSeq, uBaseTaskDL> {
    int compare( uBaseTask &t1, uBaseTask &t2 );
  public:
    void uAddInitialize( uSequence<uBaseTaskDL> &TaskList );
    void uRemoveInitialize( uSequence<uBaseTaskDL> & );
    void uRescheduleTask( uBaseTaskDL *TaskNode, uBaseTaskSeq &TaskList );
}; // uDeadlineMonotonicStatic


#pragma __U_USER_CODE__

#endif // __U_DEADLINEMONOTONIC_H__


// Local Variables: //
// compile-command: "gmake install" //
// End: //

==> u++_5.3.0.orig.tar.gz: u++-5.3.0/src/scheduler/uDeadlineMonotonicStatic.h <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
// 
// uDeadlineMonotonic.h -- 
// 
// Author           : Ashif S. Harji
// Created On       : Fri Oct 27 16:09:42 2000
// Last Modified By : Peter A. Buhr
// Last Modified On : Mon Oct 10 11:12:01 2005
// Update Count     : 151
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __U_DEADLINEMONOTONICSTATIC_H__
#define __U_DEADLINEMONOTONICSTATIC_H__

#pragma __U_NOT_USER_CODE__


#include <uRealTime.h>
#include <uStaticPriorityQ.h>


class uDeadlineMonotonicStatic : public uStaticPriorityScheduleSeq<uBaseTaskSeq, uBaseTaskDL> {
    int compare( uBaseTask &t1, uBaseTask &t2 );
  public:
    void addInitialize( uSequence<uBaseTaskDL> &TaskList );
    void removeInitialize( uSequence<uBaseTaskDL> & );
    void uRescheduleTask( uBaseTaskDL *TaskNode, uBaseTaskSeq &TaskList );
}; // uDeadlineMonotonicStatic


#pragma __U_USER_CODE__

#endif // __U_DEADLINEMONOTONIC_H__


// Local Variables: //
// compile-command: "gmake install" //
// End: //
